@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2002-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 #include "classifier.h"
 
@@ -34,8 +34,8 @@
 #include "icon_utils.h"
 
 // kde includes
-#include <KLocalizedString>
-#include <KMessageBox>
+#include <klocale.h>
+#include <kmessagebox.h>
 
 // qt includes
 #include <QPointer>
@@ -85,25 +85,20 @@ void UMLClassifier::setBaseType(UMLObject::ObjectType ot)
     Icon_Utils::IconType newIcon;
     switch (ot) {
         case ot_Interface:
-            UMLObject::setStereotypeCmd(QLatin1String("interface"));
+            UMLObject::setStereotype("interface");
             UMLObject::m_bAbstract = true;
             newIcon = Icon_Utils::it_Interface;
             break;
         case ot_Class:
-            UMLObject::setStereotypeCmd(QString());
+            UMLObject::setStereotype(QString());
             UMLObject::m_bAbstract = false;
             newIcon = Icon_Utils::it_Class;
             break;
         case ot_Datatype:
-            UMLObject::setStereotypeCmd(QLatin1String("datatype"));
+            UMLObject::setStereotype("datatype");
             UMLObject::m_bAbstract = false;
             newIcon = Icon_Utils::it_Datatype;
             break;
-        case ot_Package:
-            UMLObject::setStereotypeCmd(QLatin1String("package"));
-            UMLObject::m_bAbstract = false;
-            newIcon = Icon_Utils::it_Package;
-            break;
         default:
             uError() << "cannot set to type " << ot;
             return;
@@ -144,7 +139,7 @@ UMLOperation * UMLClassifier::checkOperationSignature(
         UMLOperation *exemptOp)
 {
     UMLOperationList list = findOperations(name);
-    if (list.count() == 0) {
+    if ( list.count() == 0 ) {
         return NULL;
     }
     const int inputParmCount = opParams.count();
@@ -154,24 +149,24 @@ UMLOperation * UMLClassifier::checkOperationSignature(
         if (test == exemptOp) {
             continue;
         }
-        UMLAttributeList testParams = test->getParmList();
+        UMLAttributeList testParams = test->getParmList( );
         const int pCount = testParams.count();
-        if (pCount != inputParmCount) {
+        if ( pCount != inputParmCount ) {
             continue;
         }
         int i = 0;
         while (i < pCount) {
             // The only criterion for equivalence is the parameter types.
             // (Default values are not considered.)
-            if(testParams.at(i)->getTypeName() != opParams.at(i)->getTypeName())
+            if( testParams.at(i)->getTypeName() != opParams.at(i)->getTypeName() )
                 break;
             i++;
         }
-        if (i == pCount) { // all parameters matched->the signature is not unique
+        if ( i == pCount ) { // all parameters matched->the signature is not unique
             return test;
         }
     }
-    // we did not find an exact match, so the signature is unique (acceptable)
+    // we did not find an exact match, so the signature is unique ( acceptable )
     return NULL;
 }
 
@@ -193,7 +188,7 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
     // if there are operation(s) with the same name then compare the parameter list
     const int inputParmCount = params.count();
 
-    foreach (UMLOperation* test, list) {
+    foreach (UMLOperation* test, list ) {
         UMLAttributeList testParams = test->getParmList();
         const int pCount = testParams.count();
         if (inputParmCount == 0 && pCount == 0)
@@ -208,7 +203,7 @@ UMLOperation* UMLClassifier::findOperation(const QString& name,
             if (type == NULL && testType == NULL) { //no parameter type
                 continue;
             } else if (type == NULL) {  //template parameter
-                if (testType->name() != QLatin1String("class"))
+                if (testType->name() != "class")
                     break;
             } else if (type != testType)
                 break;
@@ -260,7 +255,7 @@ UMLOperation* UMLClassifier::createOperation(
     // we did not find an exact match, so the signature is unique
     UMLOperation *op = new UMLOperation(this, name);
     if (params) {
-        for (Model_Utils::NameAndType_ListIt it = params->begin(); it != params->end(); ++it) {
+        for (Model_Utils::NameAndType_ListIt it = params->begin(); it != params->end(); ++it ) {
             const Model_Utils::NameAndType &nt = *it;
             UMLAttribute *par = new UMLAttribute(op, nt.m_name, Uml::ID::None, Uml::Visibility::Private,
                                                  nt.m_type, nt.m_initialValue);
@@ -268,21 +263,18 @@ UMLOperation* UMLClassifier::createOperation(
             op->addParm(par);
         }
     }
-
-    // Only show the operation dialog if no name was provided (allows quick-create
-    // from listview)
-    if (nameNotSet) {
-        op->setName(uniqChildName(UMLObject::ot_Operation));
-
+    if (nameNotSet || params == NULL) {
+        if (nameNotSet)
+            op->setName( uniqChildName(UMLObject::ot_Operation) );
         while (true) {
             QPointer<UMLOperationDialog> operationDialog = new UMLOperationDialog(0, op);
-            if(operationDialog->exec() != QDialog::Accepted) {
+            if( operationDialog->exec() != KDialog::Accepted ) {
                 delete op;
                 delete operationDialog;
                 return NULL;
             } else if (checkOperationSignature(op->name(), op->getParmList())) {
                 KMessageBox::information(0,
-                                         i18n("An operation with the same name and signature already exists. You cannot add it again."));
+                                         i18n("An operation with the same name and signature already exists. You can not add it again."));
             } else {
                 break;
             }
@@ -309,25 +301,25 @@ UMLOperation* UMLClassifier::createOperation(
  * @param position   Inserted at the given position.
  * @return           True if the operation was added successfully.
  */
-bool UMLClassifier::addOperation(UMLOperation* op, int position)
+bool UMLClassifier::addOperation(UMLOperation* op, int position )
 {
     Q_ASSERT(op);
     if (m_List.indexOf(op) != -1) {
         uDebug() << "findRef(" << op->name() << ") finds op (bad)";
         return false;
     }
-    if (checkOperationSignature(op->name(), op->getParmList())) {
+    if (checkOperationSignature(op->name(), op->getParmList()) ) {
         uDebug() << "checkOperationSignature(" << op->name() << ") op is non-unique";
         return false;
     }
 
-    if (position >= 0 && position <= m_List.count()) {
+    if ( position >= 0 && position <= m_List.count() ) {
         uDebug() << op->name() << ": inserting at position " << position;
         m_List.insert(position, op);
         UMLClassifierListItemList itemList = getFilteredList(UMLObject::ot_Operation);
         QString buf;
-        foreach (UMLClassifierListItem* currentAtt, itemList) {
-            buf.append(QLatin1Char(' ') + currentAtt->name());
+        foreach (UMLClassifierListItem* currentAtt, itemList ) {
+            buf.append(' ' + currentAtt->name());
         }
         uDebug() << "  list after change: " << buf;
     }
@@ -351,11 +343,11 @@ bool UMLClassifier::addOperation(UMLOperation* op, int position)
  */
 bool UMLClassifier::addOperation(UMLOperation* op, IDChangeLog* log)
 {
-    if (addOperation(op, -1)) {
+    if ( addOperation(op, -1) ) {
         return true;
     }
     else if (log) {
-        log->removeChangeByNewID(op->id());
+        log->removeChangeByNewID( op->id() );
     }
     return false;
 }
@@ -401,9 +393,9 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
     }
     UMLTemplate* newTemplate = new UMLTemplate(this, name);
 
-    int button = QDialog::Accepted;
+    int button = KDialog::Accepted;
 
-    while (button == QDialog::Accepted && !goodName) {
+    while (button == KDialog::Accepted && !goodName) {
         QPointer<UMLTemplateDialog> templateDialog = new UMLTemplateDialog(0, newTemplate);
         button = templateDialog->exec();
         name = newTemplate->name();
@@ -411,7 +403,7 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
         if (name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
         }
-        else if (findChildObject(name) != NULL) {
+        else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         }
         else {
@@ -420,7 +412,7 @@ UMLObject* UMLClassifier::createTemplate(const QString& currentName /*= QString(
         delete templateDialog;
     }
 
-    if (button != QDialog::Accepted) {
+    if (button != KDialog::Accepted) {
         return NULL;
     }
 
@@ -449,7 +441,7 @@ int UMLClassifier::attributes()
 UMLAttributeList UMLClassifier::getAttributeList() const
 {
     UMLAttributeList attributeList;
-    foreach (UMLObject* listItem, m_List) {
+    foreach (UMLObject* listItem , m_List ) {
         uIgnoreZeroPointer(listItem);
         if (listItem->baseType() == UMLObject::ot_Attribute) {
             attributeList.append(static_cast<UMLAttribute*>(listItem));
@@ -504,7 +496,7 @@ UMLAttributeList UMLClassifier::getAttributeListStatic(Visibility::Enum scope) c
     if (!isInterface())
     {
         UMLAttributeList atl = getAttributeList();
-        foreach(UMLAttribute* at, atl)
+        foreach(UMLAttribute* at, atl )
         {
             uIgnoreZeroPointer(at);
             if (at->isStatic())
@@ -566,7 +558,7 @@ UMLObject* UMLClassifier::findChildObjectById(Uml::ID::Type id, bool considerAnc
     }
     if (considerAncestors) {
         UMLClassifierList ancestors = findSuperClassConcepts();
-        foreach (UMLClassifier *anc, ancestors) {
+        foreach (UMLClassifier *anc , ancestors ) {
             UMLObject *o = anc->findChildObjectById(id);
             if (o) {
                 return o;
@@ -589,7 +581,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
 
     UMLClassifierList inheritingConcepts;
     Uml::ID::Type myID = id();
-    foreach(UMLClassifier *c, list) {
+    foreach(UMLClassifier *c , list ) {
         uIgnoreZeroPointer(c);
         if (type == ALL || (!c->isInterface() && type == CLASS)
                 || (c->isInterface() && type == INTERFACE)) {
@@ -597,7 +589,7 @@ UMLClassifierList UMLClassifier::findSubClassConcepts (ClassifierType type)
         }
     }
 
-    foreach (UMLAssociation *a, rlist) {
+    foreach (UMLAssociation *a , rlist ) {
         uIgnoreZeroPointer(a);
         if (a->getObjectId(RoleType::A) != myID)
         {
@@ -628,14 +620,14 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
 
     UMLClassifierList parentConcepts;
     Uml::ID::Type myID = id();
-    foreach (UMLClassifier *concept, list) {
+    foreach (UMLClassifier *concept , list ) {
         uIgnoreZeroPointer(concept);
         if (type == ALL || (!concept->isInterface() && type == CLASS)
                 || (concept->isInterface() && type == INTERFACE))
             parentConcepts.append(concept);
     }
 
-    foreach (UMLAssociation *a, rlist) {
+    foreach (UMLAssociation *a , rlist ) {
         if (a->getObjectId(RoleType::A) == myID)
         {
             UMLObject* obj = a->getObject(RoleType::B);
@@ -655,6 +647,14 @@ UMLClassifierList UMLClassifier::findSuperClassConcepts (ClassifierType type)
  */
 bool UMLClassifier::operator==(const UMLClassifier & rhs) const
 {
+  /*
+    if ( m_List.count() != rhs.m_List.count() ) {
+        return false;
+    }
+    if ( &m_List != &(rhs.m_List) ) {
+        return false;
+    }
+   */
     return UMLCanvasObject::operator==(rhs);
 }
 
@@ -693,7 +693,7 @@ bool UMLClassifier::resolveRef()
 {
     bool success = UMLPackage::resolveRef();
     // Using reentrant iteration is a bare necessity here:
-    foreach (UMLObject* obj, m_List) {
+    foreach (UMLObject* obj, m_List ) {
         uIgnoreZeroPointer(obj);
         /**** For reference, here is the non-reentrant iteration scheme -
               DO NOT USE THIS !
@@ -767,19 +767,19 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
     }
     UMLAttribute* newAttribute = new UMLAttribute(this, currentName, id, vis, type, init);
 
-    int button = QDialog::Accepted;
+    int button = KDialog::Accepted;
     bool goodName = false;
 
     //check for name.isNull() stops dialog being shown
     //when creating attribute via list view
-    while (button == QDialog::Accepted && !goodName && name.isNull()) {
+    while (button == KDialog::Accepted && !goodName && name.isNull()) {
         QPointer<UMLAttributeDialog> attributeDialog = new UMLAttributeDialog(0, newAttribute);
         button = attributeDialog->exec();
         QString name = newAttribute->name();
 
         if(name.length() == 0) {
             KMessageBox::error(0, i18n("That is an invalid name."), i18n("Invalid Name"));
-        } else if (findChildObject(name) != NULL) {
+        } else if ( findChildObject(name) != NULL ) {
             KMessageBox::error(0, i18n("That name is already being used."), i18n("Not a Unique Name"));
         } else {
             goodName = true;
@@ -787,7 +787,7 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
         delete attributeDialog;
     }
 
-    if (button != QDialog::Accepted) {
+    if (button != KDialog::Accepted) {
         delete newAttribute;
         return NULL;
     }
@@ -809,7 +809,7 @@ UMLAttribute* UMLClassifier::createAttribute(const QString &name,
 
 UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::ID::Type id /* = Uml::id_None */)
 {
-    foreach (UMLObject* obj, m_List) {
+    foreach (UMLObject* obj, m_List ) {
         uIgnoreZeroPointer(obj);
         if (obj->baseType() == UMLObject::ot_Attribute && obj->name() == name)
             return static_cast<UMLAttribute*>(obj);
@@ -819,7 +819,7 @@ UMLAttribute* UMLClassifier::addAttribute(const QString &name, Uml::ID::Type id
     m_List.append(a);
     emit attributeAdded(a);
     UMLObject::emitModified();
-    connect(a, SIGNAL(modified()), this, SIGNAL(modified()));
+    connect(a,SIGNAL(modified()),this,SIGNAL(modified()));
     return a;
 }
 
@@ -900,7 +900,7 @@ int UMLClassifier::removeAttribute(UMLAttribute* att)
     UMLObject::emitModified();
     // If we are deleting the object, then we don't need to disconnect..this is done auto-magically
     // for us by QObject. -b.t.
-    // disconnect(att, SIGNAL(modified()), this, SIGNAL(modified()));
+    // disconnect(att, SIGNAL(modified()), this,SIGNAL(modified()));
     delete att;
     return m_List.count();
 }
@@ -929,8 +929,8 @@ UMLAssociation *UMLClassifier::getClassAssoc() const
  */
 bool UMLClassifier::hasAbstractOps ()
 {
-    UMLOperationList opl(getOpList());
-    foreach(UMLOperation *op, opl) {
+    UMLOperationList opl( getOpList() );
+    foreach(UMLOperation *op , opl ) {
         uIgnoreZeroPointer(op);
         if (op->isAbstract()) {
             return true;
@@ -986,10 +986,10 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited, UMLClassifierSe
             // get operations for each parent by recursive call
             UMLOperationList pops = c->getOpList(true, alreadyTraversed);
             // add these operations to operation list, but only if unique.
-            foreach (UMLOperation *po, pops) {
+            foreach (UMLOperation *po , pops ) {
                 QString po_as_string(po->toString(Uml::SignatureType::SigNoVis));
                 bool breakFlag = false;
-                foreach (UMLOperation* o,  ops) {
+                foreach (UMLOperation* o ,  ops ) {
                     if (o->toString(Uml::SignatureType::SigNoVis) == po_as_string) {
                         breakFlag = true;
                         break;
@@ -1070,11 +1070,11 @@ bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* =
         m_List.append(newTemplate);
         emit templateAdded(newTemplate);
         UMLObject::emitModified();
-        connect(newTemplate, SIGNAL(modified()), this, SIGNAL(modified()));
+        connect(newTemplate,SIGNAL(modified()),this,SIGNAL(modified()));
         return true;
     }
     else if (log) {
-        log->removeChangeByNewID(newTemplate->id());
+        log->removeChangeByNewID( newTemplate->id() );
         delete newTemplate;
     }
     return false;
@@ -1092,11 +1092,10 @@ bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* =
  */
 bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
 {
-    Q_ASSERT(templt);
     QString name = templt->name();
     if (findChildObject(name) == NULL) {
         templt->setParent(this);
-        if (position >= 0 && position <= (int)m_List.count()) {
+        if ( position >= 0 && position <= (int)m_List.count() ) {
             m_List.insert(position, templt);
         }
         else {
@@ -1120,7 +1119,7 @@ bool UMLClassifier::addTemplate(UMLTemplate* templt, int position)
  */
 int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
 {
-    if (!m_List.removeAll(umltemplate)) {
+    if ( !m_List.removeAll(umltemplate) ) {
         uWarning() << "cannot find att given in list";
         return -1;
     }
@@ -1138,7 +1137,7 @@ int UMLClassifier::removeTemplate(UMLTemplate* umltemplate)
 UMLTemplate *UMLClassifier::findTemplate(const QString& name)
 {
     UMLTemplateList templParams = getTemplateList();
-    foreach (UMLTemplate *templt, templParams) {
+    foreach (UMLTemplate *templt , templParams) {
         if (templt->name() == name) {
             return templt;
         }
@@ -1187,13 +1186,13 @@ UMLTemplateList UMLClassifier::getTemplateList() const
 int UMLClassifier::takeItem(UMLClassifierListItem *item)
 {
     QString buf;
-    foreach (UMLObject* currentAtt, m_List) {
+    foreach (UMLObject* currentAtt, m_List ) {
         uIgnoreZeroPointer(currentAtt);
         QString txt = currentAtt->name();
         if (txt.isEmpty()) {
-           txt = QLatin1String("Type-") + QString::number((int) currentAtt->baseType());
+           txt = "Type-" + QString::number((int) currentAtt->baseType());
         }
-        buf.append(QLatin1Char(' ') + currentAtt->name());
+        buf.append(' ' + currentAtt->name());
     }
     uDebug() << "  UMLClassifier::takeItem (before): m_List is " << buf;
 
@@ -1209,7 +1208,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
             break;
         }
         case UMLObject::ot_Attribute: {
-            UMLAttribute *retval = dynamic_cast<UMLAttribute*>(m_List.takeAt(index).data());
+            UMLAttribute *retval = dynamic_cast<UMLAttribute*>(m_List.takeAt( index ));
             if (retval) {
                 emit attributeRemoved(retval);
                 UMLObject::emitModified();
@@ -1219,7 +1218,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
             break;
         }
         case UMLObject::ot_Template: {
-            UMLTemplate *templt = dynamic_cast<UMLTemplate*>(m_List.takeAt(index).data());
+            UMLTemplate *templt = dynamic_cast<UMLTemplate*>(m_List.takeAt( index));
             if (templt) {
                 emit templateRemoved(templt);
                 UMLObject::emitModified();
@@ -1229,7 +1228,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
             break;
         }
         case UMLObject::ot_EnumLiteral: {
-            UMLEnumLiteral *el = dynamic_cast<UMLEnumLiteral*>(m_List.takeAt(index).data());
+            UMLEnumLiteral *el = dynamic_cast<UMLEnumLiteral*>(m_List.takeAt( index ) );
             if (el) {
                 UMLEnum *e = static_cast<UMLEnum*>(this);
                 e->signalEnumLiteralRemoved(el);
@@ -1240,7 +1239,7 @@ int UMLClassifier::takeItem(UMLClassifierListItem *item)
             break;
         }
         case UMLObject::ot_EntityAttribute: {
-            UMLEntityAttribute* el = dynamic_cast<UMLEntityAttribute*>(m_List.takeAt(index).data());
+            UMLEntityAttribute* el = dynamic_cast<UMLEntityAttribute*>(m_List.takeAt( index));
             if (el) {
                 UMLEntity *e = static_cast<UMLEntity*>(this);
                 e->signalEntityAttributeRemoved(el);
@@ -1272,7 +1271,7 @@ void UMLClassifier::setOriginType(UMLClassifier *origType)
  */
 UMLClassifier * UMLClassifier::originType() const
 {
-    return dynamic_cast<UMLClassifier*>(m_pSecondary.data());
+    return static_cast<UMLClassifier*>(m_pSecondary);
 }
 
 /**
@@ -1382,7 +1381,7 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
             UMLAttributeList atl = getAttributeList();
             bool found = false;
             //make sure that an attribute with the same name doesn't already exist
-            foreach (UMLAttribute *at, atl) {
+            foreach (UMLAttribute *at , atl ) {
                 uIgnoreZeroPointer(a);
                 if (at->name() == roleNameB) {
                     found = true;
@@ -1398,27 +1397,21 @@ UMLAssociationList  UMLClassifier::getUniAssociationToBeImplemented()
 }
 
 /**
- * Creates XML tag <UML:Class>, <UML:Interface>, or <UML:DataType>
- * depending on m_BaseType.
- * Saves possible template parameters, generalizations, attributes,
- * operations, and contained objects to the given QDomElement.
+ * Auxiliary to saveToXMI of inheriting classes:
+ * Saves template parameters to the given QDomElement.
  */
 void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
     QString tag;
     switch (m_BaseType) {
         case UMLObject::ot_Class:
-            tag = QLatin1String("UML:Class");
+            tag = "UML:Class";
             break;
         case UMLObject::ot_Interface:
-            tag = QLatin1String("UML:Interface");
+            tag = "UML:Interface";
             break;
         case UMLObject::ot_Datatype:
-            tag = QLatin1String("UML:DataType");
-            break;
-        case UMLObject::ot_Package:
-            UMLPackage::saveToXMI(qDoc, qElement);
-            return;
+            tag = "UML:DataType";
             break;
         default:
             uError() << "internal error: basetype is " << m_BaseType;
@@ -1426,63 +1419,62 @@ void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
     }
     QDomElement classifierElement = UMLObject::save(tag, qDoc);
     if (m_BaseType == UMLObject::ot_Datatype && m_pSecondary != NULL)
-        classifierElement.setAttribute(QLatin1String("elementReference"),
-                                        Uml::ID::toString(m_pSecondary->id()));
+        classifierElement.setAttribute( "elementReference",
+                                        Uml::ID::toString(m_pSecondary->id()) );
 
     //save templates
     UMLClassifierListItemList list = getFilteredList(UMLObject::ot_Template);
     if (list.count()) {
-        QDomElement tmplElement = qDoc.createElement(QLatin1String("UML:ModelElement.templateParameter"));
-        foreach (UMLClassifierListItem *tmpl, list) {
+        QDomElement tmplElement = qDoc.createElement( "UML:ModelElement.templateParameter" );
+        foreach (UMLClassifierListItem *tmpl , list ) {
             tmpl->saveToXMI(qDoc, tmplElement);
         }
-        classifierElement.appendChild(tmplElement);
+        classifierElement.appendChild( tmplElement );
     }
 
     //save generalizations (we are the subclass, the other end is the superclass)
     UMLAssociationList generalizations = getSpecificAssocs(AssociationType::Generalization);
     if (generalizations.count()) {
-        QDomElement genElement = qDoc.createElement(QLatin1String("UML:GeneralizableElement.generalization"));
-        foreach (UMLAssociation *a, generalizations) {
+        QDomElement genElement = qDoc.createElement("UML:GeneralizableElement.generalization");
+        foreach (UMLAssociation *a , generalizations ) {
             // We are the subclass if we are at the role A end.
             if (m_nId != a->getObjectId(RoleType::A)) {
                 continue;
             }
-            QDomElement gElem = qDoc.createElement(QLatin1String("UML:Generalization"));
-            gElem.setAttribute(QLatin1String("xmi.idref"), Uml::ID::toString(a->id()));
+            QDomElement gElem = qDoc.createElement("UML:Generalization");
+            gElem.setAttribute( "xmi.idref", Uml::ID::toString(a->id()) );
             genElement.appendChild(gElem);
         }
         if (genElement.hasChildNodes()) {
-            classifierElement.appendChild(genElement);
+            classifierElement.appendChild( genElement );
         }
     }
 
     // save attributes
-    QDomElement featureElement = qDoc.createElement(QLatin1String("UML:Classifier.feature"));
+    QDomElement featureElement = qDoc.createElement( "UML:Classifier.feature" );
     UMLClassifierListItemList attList = getFilteredList(UMLObject::ot_Attribute);
-    foreach (UMLClassifierListItem *pAtt, attList) {
-        pAtt->saveToXMI(qDoc, featureElement);
+    foreach (UMLClassifierListItem *pAtt , attList ) {
+        pAtt->saveToXMI( qDoc, featureElement );
     }
 
     // save operations
     UMLOperationList opList = getOpList();
-    foreach (UMLOperation *pOp, opList) {
-        pOp->saveToXMI(qDoc, featureElement);
+    foreach (UMLOperation *pOp , opList ) {
+        pOp->saveToXMI( qDoc, featureElement );
     }
     if (featureElement.hasChildNodes()) {
-        classifierElement.appendChild(featureElement);
+        classifierElement.appendChild( featureElement );
     }
 
     // save contained objects
     if (m_objects.count()) {
-        QDomElement ownedElement = qDoc.createElement(QLatin1String("UML:Namespace.ownedElement"));
-        foreach (UMLObject* obj, m_objects) {
-            uIgnoreZeroPointer(obj);
+        QDomElement ownedElement = qDoc.createElement( "UML:Namespace.ownedElement" );
+        foreach (UMLObject* obj, m_objects ) {
             obj->saveToXMI (qDoc, ownedElement);
         }
-        classifierElement.appendChild(ownedElement);
+        classifierElement.appendChild( ownedElement );
     }
-    qElement.appendChild(classifierElement);
+    qElement.appendChild( classifierElement );
 }
 
 /**
@@ -1495,15 +1487,13 @@ void UMLClassifier::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 UMLClassifierListItem* UMLClassifier::makeChildObject(const QString& xmiTag)
 {
     UMLClassifierListItem* pObject = NULL;
-    if (UMLDoc::tagEq(xmiTag, QLatin1String("Operation")) ||
-        UMLDoc::tagEq(xmiTag, QLatin1String("ownedOperation"))) {
+    if (UMLDoc::tagEq(xmiTag, "Operation")) {
         pObject = new UMLOperation(this);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("Attribute")) ||
-               UMLDoc::tagEq(xmiTag, QLatin1String("ownedAttribute"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "Attribute")) {
         if (baseType() != UMLObject::ot_Class)
             return NULL;
         pObject = new UMLAttribute(this);
-    } else if (UMLDoc::tagEq(xmiTag, QLatin1String("TemplateParameter"))) {
+    } else if (UMLDoc::tagEq(xmiTag, "TemplateParameter")) {
         pObject = new UMLTemplate(this);
     }
     return pObject;
@@ -1519,7 +1509,7 @@ UMLClassifierListItem* UMLClassifier::makeChildObject(const QString& xmiTag)
 bool UMLClassifier::load(QDomElement& element)
 {
     UMLClassifierListItem *child = NULL;
-    m_SecondaryId = element.attribute(QLatin1String("elementReference"));
+    m_SecondaryId = element.attribute( "elementReference", "" );
     if (!m_SecondaryId.isEmpty()) {
         // @todo We do not currently support composition.
         m_isRef = true;
@@ -1531,12 +1521,10 @@ bool UMLClassifier::load(QDomElement& element)
             continue;
         element = node.toElement();
         QString tag = element.tagName();
-        QString stereotype = element.attribute(QLatin1String("stereotype"));
-        if (UMLDoc::tagEq(tag, QLatin1String("ModelElement.templateParameter")) ||
-                UMLDoc::tagEq(tag, QLatin1String("Classifier.feature")) ||
-                UMLDoc::tagEq(tag, QLatin1String("Namespace.ownedElement")) ||
-                UMLDoc::tagEq(tag, QLatin1String("Element.ownedElement")) ||  // Embarcadero's Describe
-                UMLDoc::tagEq(tag, QLatin1String("Namespace.contents"))) {
+        if (UMLDoc::tagEq(tag, "ModelElement.templateParameter") ||
+                UMLDoc::tagEq(tag, "Classifier.feature") ||
+                UMLDoc::tagEq(tag, "Namespace.ownedElement") ||
+                UMLDoc::tagEq(tag, "Namespace.contents")) {
             load(element);
             // Not evaluating the return value from load()
             // because we want a best effort.
@@ -1545,17 +1533,17 @@ bool UMLClassifier::load(QDomElement& element)
             if (child->loadFromXMI(element)) {
                 switch (child->baseType()) {
                     case UMLObject::ot_Template:
-                        addTemplate(static_cast<UMLTemplate*>(child));
+                        addTemplate( static_cast<UMLTemplate*>(child) );
                         break;
                     case UMLObject::ot_Operation:
-                        if (! addOperation(static_cast<UMLOperation*>(child))) {
+                        if (! addOperation(static_cast<UMLOperation*>(child)) ) {
                             uError() << "error from addOperation(op)";
                             delete child;
                             totalSuccess = false;
                         }
                         break;
                     case UMLObject::ot_Attribute:
-                        addAttribute(static_cast<UMLAttribute*>(child));
+                        addAttribute( static_cast<UMLAttribute*>(child) );
                         break;
                     default:
                         break;
@@ -1566,7 +1554,7 @@ bool UMLClassifier::load(QDomElement& element)
                 totalSuccess = false;
             }
         } else if (!Model_Utils::isCommonXMIAttribute(tag)) {
-            UMLObject *pObject = Object_Factory::makeObjectFromXMI(tag, stereotype);
+            UMLObject *pObject = Object_Factory::makeObjectFromXMI(tag);
             if (pObject == NULL) {
                 // Not setting totalSuccess to false
                 // because we want a best effort.
@@ -1629,3 +1617,4 @@ UMLClassifierList UMLClassifier::findAssocClassifierObjsInRoles (UMLAssociationL
 */
 
 
+#include "classifier.moc"
