@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2005-2013                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -26,7 +26,6 @@
 #include "template.h"
 #include "uml.h"
 #include "umldoc.h"
-#include "umllistview.h"
 #include "umlobject.h"
 #include "umbrellosettings.h"
 
@@ -38,10 +37,6 @@
 #include <QMap>
 #include <QRegExp>
 
-DEBUG_REGISTER_DISABLED(Import_Utils)
-#undef DBG_SRC
-#define DBG_SRC QLatin1String("Import_Utils")
-
 namespace Import_Utils {
 
 /**
@@ -123,10 +118,10 @@ QString formatComment(const QString &comment)
     if (comment.isEmpty())
         return comment;
 
-    QStringList lines = comment.split(QLatin1Char('\n'));
+    QStringList lines = comment.split('\n');
     QString& first = lines.first();
-    QRegExp wordex(QLatin1String("\\w"));
-    if (first.startsWith(QLatin1String(QLatin1String("/*")))) {
+    QRegExp wordex("\\w");
+    if (first.startsWith(QLatin1String("/*"))) {
         int wordpos = wordex.indexIn(first);
         if (wordpos != -1)
             first = first.mid(wordpos);  // remove comment start
@@ -137,7 +132,7 @@ QString formatComment(const QString &comment)
         return QString();
 
     QString& last = lines.last();
-    int endpos = last.indexOf(QLatin1String("*/"));
+    int endpos = last.indexOf("*/");
     if (endpos != -1) {
         if (last.contains(wordex))
             last = last.mid(0, endpos - 1);  // remove comment end
@@ -149,10 +144,10 @@ QString formatComment(const QString &comment)
 
     QStringList::Iterator end(lines.end());
     for (QStringList::Iterator lit(lines.begin()); lit != end; ++lit) {
-        (*lit).remove(QRegExp(QLatin1String("^\\s+")));
-        (*lit).remove(QRegExp(QLatin1String("^\\*+\\s?")));
+        (*lit).remove(QRegExp("^\\s+"));
+        (*lit).remove(QRegExp("^\\*+\\s?"));
     }
-    return lines.join(QLatin1String("\n"));
+    return lines.join("\n");
 }
 
 /*
@@ -171,46 +166,42 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
                            const QString& inName,
                            UMLPackage *parentPkg,
                            const QString& comment,
-                           const QString& stereotype,
-                           bool searchInParentPackageOnly)
+                           const QString& stereotype)
 {
     QString name = inName;
     UMLDoc *umldoc = UMLApp::app()->document();
+    if (type == UMLObject::ot_Artifact) {
+        if (!Settings::optionState().codeImportState.createArtifacts)
+            return 0;
+        QFileInfo fi(name);
+        UMLFolder *componentView = umldoc->rootFolder(Uml::ModelType::Component);
+        UMLObject *o = umldoc->findUMLObjectRaw(componentView, fi.fileName(), type);
+        if (o)
+            return o;
+        o = Object_Factory::createUMLObject(type, fi.fileName(), componentView, false);
+        UMLArtifact *a = static_cast<UMLArtifact*>(o);
+        a->setDrawAsType(UMLArtifact::file);
+        a->setDoc(comment);
+        uDebug() << name << comment;
+        return o;
+    }
     UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
     if (parentPkg == NULL) {
-        // DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
+        // uDebug() << "Import_Utils::createUMLObject(" << name
         //     << "): parentPkg is NULL, assuming Logical View";
         parentPkg = logicalView;
-    } else if (parentPkg->baseType() == UMLObject::ot_Artifact) {
-        DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
-                       << "): Artifact as parent package is not supported yet, using Logical View";
-        parentPkg = logicalView;
-    } else if (parentPkg->baseType() == UMLObject::ot_Association) {
-        DEBUG(DBG_SRC) << "Import_Utils::createUMLObject(" << name
-                       << "): Association as parent package is not supported yet, using Logical View";
-        parentPkg = logicalView;
-    } else if (name.startsWith(QLatin1String("::"))) {
-        name = name.mid(2);
-        parentPkg = logicalView;
     }
-    UMLObject *o = umldoc->findUMLObject(name, type, parentPkg);
+    UMLObject * o = umldoc->findUMLObject(name, type, parentPkg);
     bNewUMLObjectWasCreated = false;
-    if (searchInParentPackageOnly) {
-        if (o && o->umlPackage() != parentPkg) {
-            o = Object_Factory::createNewUMLObject(type, name, parentPkg);
-            bNewUMLObjectWasCreated = true;
-            bPutAtGlobalScope = false;
-        }
-    }
     if (o == NULL) {
         // Strip possible adornments and look again.
-        const bool isConst = name.contains(QRegExp(QLatin1String("^const ")));
-        name.remove(QRegExp(QLatin1String("^const\\s+")));
+        const bool isConst = name.contains(QRegExp("^const "));
+        name.remove(QRegExp("^const\\s+"));
         QString typeName(name);
-        bool isAdorned = typeName.contains(QRegExp(QLatin1String("[^\\w:\\. ]")));
-        const bool isPointer = typeName.contains(QLatin1Char('*'));
-        const bool isRef = typeName.contains(QLatin1Char('&'));
-        typeName.remove(QRegExp(QLatin1String("[^\\w:\\. ].*$")));
+        bool isAdorned = typeName.contains( QRegExp("[^\\w:\\. ]") );
+        const bool isPointer = typeName.contains('*');
+        const bool isRef = typeName.contains('&');
+        typeName.remove(QRegExp("[^\\w:\\. ].*$"));
         typeName = typeName.simplified();
         UMLObject *origType = umldoc->findUMLObject(typeName, UMLObject::ot_UMLObject, parentPkg);
         if (origType == NULL) {
@@ -219,20 +210,20 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
                 parentPkg = logicalView;
             // Find, or create, the scopes.
             QStringList components;
-            if (typeName.contains(QLatin1String("::"))) {
-                components = typeName.split(QLatin1String("::"), QString::SkipEmptyParts);
-            } else if (typeName.contains(QLatin1String("..."))) {
+            if (typeName.contains("::")) {
+                components = typeName.split("::");
+            } else if (typeName.contains("...")) {
                 // Java variable length arguments
                 type = UMLObject::ot_Datatype;
                 parentPkg = umldoc->datatypeFolder();
                 isAdorned = false;
-            } else if (typeName.contains(QLatin1String("."))) {
-                components = typeName.split(QLatin1Char('.'));
+            } else if (typeName.contains(".")) {
+                components = typeName.split('.');
             }
             if (components.count() > 1) {
                 typeName = components.back();
                 components.pop_back();
-                while (components.count()) {
+                while ( components.count() ) {
                     QString scopeName = components.front();
                     components.pop_front();
                     o = umldoc->findUMLObject(scopeName, UMLObject::ot_UMLObject, parentPkg);
@@ -240,11 +231,19 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
                         parentPkg = static_cast<UMLPackage*>(o);
                         continue;
                     }
-                    o = Object_Factory::createUMLObject(UMLObject::ot_Class, scopeName, parentPkg);
-                    o->setStereotypeCmd(QLatin1String("class-or-package"));
-                    UMLListViewItem *item = UMLApp::app()->listView()->findUMLObject(o);
-                    if (item)
-                        item->updateObject();
+                    int wantNamespace = KMessageBox::Yes;
+                    const Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
+                    if (pl == Uml::ProgrammingLanguage::Cpp) {
+                        // We know std and Qt are namespaces.
+                        if (scopeName != "std" && scopeName != "Qt") {
+                            wantNamespace = KMessageBox::questionYesNo(NULL,
+                                        i18n("Is the scope %1 a namespace or a class?", scopeName),
+                                        i18n("C++ Import Requests Your Help"),
+                                        KGuiItem(i18nc("namespace scope", "Namespace")), KGuiItem(i18nc("class scope", "Class")));
+                        }
+                    }
+                    UMLObject::ObjectType ot = (wantNamespace == KMessageBox::Yes ? UMLObject::ot_Package : UMLObject::ot_Class);
+                    o = Object_Factory::createUMLObject(ot, scopeName, parentPkg);
                     parentPkg = static_cast<UMLPackage*>(o);
                     Model_Utils::treeViewSetCurrentItem(o);
                 }
@@ -261,7 +260,7 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
         if (isConst || isAdorned) {
             // Create the full given type (including adornments.)
             if (isConst)
-                name.prepend(QLatin1String("const "));
+                name.prepend("const ");
             o = Object_Factory::createUMLObject(UMLObject::ot_Datatype, name,
                                                 umldoc->datatypeFolder(),
                                                 false); //solicitNewName
@@ -306,13 +305,13 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     }
     if (gRelatedClassifier == NULL || gRelatedClassifier == o)
         return o;
-    QRegExp templateInstantiation(QLatin1String("^[\\w:\\.]+\\s*<(.*)>"));
+    QRegExp templateInstantiation("^[\\w:\\.]+\\s*<(.*)>");
     int pos = templateInstantiation.indexIn(name);
     if (pos == -1)
         return o;
     // Create dependencies on template parameters.
     QString caption = templateInstantiation.cap(1);
-    const QStringList params = caption.split(QRegExp(QLatin1String("[^\\w:\\.]+")));
+    const QStringList params = caption.split(QRegExp("[^\\w:\\.]+"));
     if (!params.count())
         return o;
     QStringList::ConstIterator end(params.end());
@@ -357,14 +356,14 @@ UMLObject* insertAttribute(UMLClassifier *owner,
                            Uml::Visibility::Enum scope,
                            const QString& name,
                            UMLClassifier *attrType,
-                           const QString& comment /* =QString() */,
+                           const QString& comment /* ="" */,
                            bool isStatic /* =false */)
 {
     UMLObject::ObjectType ot = owner->baseType();
     Uml::ProgrammingLanguage::Enum pl = UMLApp::app()->activeLanguage();
     if (! (ot == UMLObject::ot_Class ||
            (ot == UMLObject::ot_Interface && pl == Uml::ProgrammingLanguage::Java))) {
-        DEBUG(DBG_SRC) << "insertAttribute: Don not know what to do with "
+        uDebug() << "insertAttribute: Don not know what to do with "
                  << owner->name() << " (object type " << UMLObject::toString(ot) << ")";
         return NULL;
     }
@@ -390,7 +389,7 @@ UMLObject* insertAttribute(UMLClassifier *owner,
 UMLObject* insertAttribute(UMLClassifier *owner, Uml::Visibility::Enum scope,
                            const QString& name,
                            const QString& type,
-                           const QString& comment /* =QString() */,
+                           const QString& comment /* ="" */,
                            bool isStatic /* =false */)
 {
     UMLObject *attrType = owner->findTemplate(type);
@@ -430,9 +429,9 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
                   bool isFriend, bool isConstructor,
                   const QString& comment)
 {
-    op->setVisibilityCmd(scope);
+    op->setVisibility(scope);
     if (!type.isEmpty()     // return type may be missing (constructor/destructor)
-        && type != QLatin1String("void")) {
+        && type != "void") {
         if (type == klass->name()) {
             op->setType(klass);
         } else {
@@ -453,10 +452,10 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
 
     // if the operation is friend, add it as a stereotype
     if (isFriend)
-        op->setStereotype(QLatin1String("friend"));
+        op->setStereotype("friend");
     // if the operation is a constructor, add it as a stereotype
     if (isConstructor)
-        op->setStereotype(QLatin1String("constructor"));
+        op->setStereotype("constructor");
 
     QString strippedComment = formatComment(comment);
     if (! strippedComment.isEmpty()) {
@@ -467,16 +466,16 @@ void insertMethod(UMLClassifier *klass, UMLOperation* &op,
     UMLOperation *exist = klass->checkOperationSignature(op->name(), params);
     if (exist) {
         // copy contents to existing operation
-        exist->setVisibilityCmd(scope);
+        exist->setVisibility(scope);
         exist->setStatic(isStatic);
         exist->setAbstract(isAbstract);
         if (! strippedComment.isEmpty())
             exist->setDoc(strippedComment);
         UMLAttributeList exParams = exist->getParmList();
-        for (UMLAttributeListIt it(params), exIt(exParams) ; it.hasNext() ;) {
-            UMLAttribute *param = it.next(), *exParam = exIt.next();
+        for (UMLAttributeListIt it(params), exIt( exParams ) ; it.hasNext() ;) {
+            UMLAttribute *param = it.next() , *exParam = exIt.next();
             exParam->setName(param->name());
-            exParam->setVisibilityCmd(param->visibility());
+            exParam->setVisibility(param->visibility());
             exParam->setStatic(param->isStatic());
             exParam->setAbstract(param->isAbstract());
             exParam->setDoc(param->doc());
@@ -546,43 +545,13 @@ void createGeneralization(UMLClassifier *child, UMLClassifier *parent)
     umldoc->addAssociation(assoc);
 }
 
-/**
- * Create an artifact with the given name.
- */
-UMLObject *createArtifact(const QString& name,
-                          UMLPackage *parentPkg,
-                          const QString &comment)
-{
-    Q_UNUSED(parentPkg);
-
-    UMLObject::ObjectType type = UMLObject::ot_Artifact;
-    if (!Settings::optionState().codeImportState.createArtifacts)
-        return 0;
-    UMLDoc *umldoc = UMLApp::app()->document();
-    UMLFolder *componentView = umldoc->rootFolder(Uml::ModelType::Component);
-    QFileInfo fi(name);
-    UMLObject *o = umldoc->findUMLObjectRaw(componentView, fi.fileName(), type);
-    if (o)
-        return o;
-    o = Object_Factory::createUMLObject(type, fi.fileName(), componentView, false);
-    UMLArtifact *a = static_cast<UMLArtifact*>(o);
-    a->setDrawAsType(UMLArtifact::file);
-    a->setDoc(comment);
-    DEBUG(DBG_SRC) << name << comment;
-    return o;
-}
-
 /**
  * Create a generalization from the existing child UMLObject to the given
  * parent class name.
- * This method does not handle scopes well and is only a last resort.
- * The method
- *   createGeneralization(UMLClassifier *child, UMLClassifier *parent)
- * should be used instead.
  */
 void createGeneralization(UMLClassifier *child, const QString &parentName)
 {
-    UMLObject *parentObj = createUMLObject(UMLObject::ot_Class, parentName);
+    UMLObject *parentObj = createUMLObject( UMLObject::ot_Class, parentName );
     UMLClassifier *parent = static_cast<UMLClassifier*>(parentObj);
     createGeneralization(child, parent);
 }
@@ -596,9 +565,9 @@ void createGeneralization(UMLClassifier *child, const QString &parentName)
 QStringList includePathList()
 {
     QStringList includePathList(incPathList);
-    QString umbrello_incpath = QString::fromLatin1(qgetenv("UMBRELLO_INCPATH"));
+    QString umbrello_incpath = QString(qgetenv("UMBRELLO_INCPATH"));
     if (!umbrello_incpath.isEmpty()) {
-        includePathList += umbrello_incpath.split(QLatin1Char(':'));
+        includePathList += umbrello_incpath.split( ':' );
     }
     return includePathList;
 }
