@@ -4,8 +4,8 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2014                                               *
- *   Umbrello UML Modeller Authors <umbrello-devel@kde.org>                *
+ *   copyright (C) 2006-2012                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
@@ -21,21 +21,12 @@
 #include "umlview.h"
 
 // kde include files
-#if QT_VERSION >= 0x050000
-#include <KIO/Job>
-#include <KJobWidgets>
-#include <KIO/MkdirJob>
-#else
-#include <kio/netaccess.h>
-#endif
-#if QT_VERSION < 0x050000
+#include <klocale.h>
 #include <ktemporaryfile.h>
-#endif
-#include <KLocalizedString>
+#include <kio/netaccess.h>
 
 // include files for Qt
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QImage>
 #include <QImageWriter>
@@ -45,14 +36,11 @@
 #include <QRect>
 #include <QRegExp>
 #include <QSvgGenerator>
-#if QT_VERSION >= 0x050000
-#include <QTemporaryFile>
-#endif
 
 // system includes
 #include <cmath>
 
-#define DBG_IEM QLatin1String("UMLViewImageExporterModel")
+#define DBG_IEM "UMLViewImageExporterModel"
 
 DEBUG_REGISTER(UMLViewImageExporterModel)
 
@@ -71,17 +59,17 @@ QStringList UMLViewImageExporterModel::supportedImageTypes()
         // QT supported formats
         QList<QByteArray> qImageFormats = QImageWriter::supportedImageFormats();
         Q_FOREACH(const QByteArray& it, qImageFormats) {
-            const QString format = QString::fromLatin1(it.toLower());
+            const QString format = it.toLower();
             if (!s_supportedImageTypesList.contains(format))
                 s_supportedImageTypesList << format;
         }
         // specific supported formats
-        if (!s_supportedImageTypesList.contains(QLatin1String("dot")))
-            s_supportedImageTypesList << QLatin1String("dot");
-        if (!s_supportedImageTypesList.contains(QLatin1String("eps")))
-            s_supportedImageTypesList << QLatin1String("eps");
-        if (!s_supportedImageTypesList.contains(QLatin1String("svg")))
-            s_supportedImageTypesList << QLatin1String("svg");
+        if (!s_supportedImageTypesList.contains("dot"))
+            s_supportedImageTypesList << "dot";
+        if (!s_supportedImageTypesList.contains("eps"))
+            s_supportedImageTypesList << "eps";
+        if (!s_supportedImageTypesList.contains("svg"))
+            s_supportedImageTypesList << "svg";
     }
     s_supportedImageTypesList.sort();
 
@@ -119,25 +107,17 @@ QStringList UMLViewImageExporterModel::supportedMimeTypes()
 QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
 {
     const QString imgType = imageType.toLower();
-    struct lut_t { const char *key, *value; };
-    const struct lut_t lut[] =
-               { { "bmp", "image/bmp"                },
-                 { "dot", "image/x-dot"              },
-                 { "jpeg","image/jpeg"               },
-                 { "pbm", "image/x-portable-bitmap"  },
-                 { "pgm", "image/x-portable-graymap" },
-                 { "png", "image/png"                },
-                 { "ppm", "image/x-portable-pixmap"  },
-                 { "xbm", "image/x-xbitmap"          },
-                 { "xpm", "image/x-xpixmap"          },
-                 { "eps", "image/x-eps"              },
-                 { "svg", "image/svg+xml"            } };
-    const size_t lut_len = sizeof(lut) / sizeof(lut_t);
-    for (size_t i = 0; i < lut_len; i++) {
-        const lut_t& ent = lut[i];
-        if (imgType == QString::fromLatin1(ent.key))
-            return QString::fromLatin1(ent.value);
-    }
+    if (QString("bmp") == imgType) return "image/bmp";
+    if (QString("dot") == imgType) return "image/x-dot";
+    if (QString("jpeg") == imgType) return "image/jpeg";
+    if (QString("pbm") == imgType) return "image/x-portable-bitmap";
+    if (QString("pgm") == imgType) return "image/x-portable-graymap";
+    if (QString("png") == imgType) return "image/png";
+    if (QString("ppm") == imgType) return "image/x-portable-pixmap";
+    if (QString("xbm") == imgType) return "image/x-xbitmap";
+    if (QString("xpm") == imgType) return "image/x-xpixmap";
+    if (QString("eps") == imgType) return "image/x-eps";
+    if (QString("svg") == imgType) return "image/svg+xml";
     return QString();
 }
 
@@ -151,25 +131,17 @@ QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
  */
 QString UMLViewImageExporterModel::mimeTypeToImageType(const QString& mimeType)
 {
-    struct lut_t { const char *key, *value; };
-    const struct lut_t lut[] =
-               { { "image/bmp",                "bmp" },
-                 { "image/x-dot",              "dot" },
-                 { "image/jpeg",               "jpeg"},
-                 { "image/x-portable-bitmap",  "pbm" },
-                 { "image/x-portable-graymap", "pgm" },
-                 { "image/png",                "png" },
-                 { "image/x-portable-pixmap",  "ppm" },
-                 { "image/x-xbitmap",          "xbm" },
-                 { "image/x-xpixmap",          "xpm" },
-                 { "image/x-eps",              "eps" },
-                 { "image/svg+xml",            "svg" } };
-    const size_t lut_len = sizeof(lut) / sizeof(lut_t);
-    for (size_t i = 0; i < lut_len; i++) {
-        const lut_t& ent = lut[i];
-        if (mimeType == QString::fromLatin1(ent.key))
-            return QString::fromLatin1(ent.value);
-    }
+    if (QString("image/bmp") == mimeType) return "bmp";
+    if (QString("image/x-dot") == mimeType) return "dot";
+    if (QString("image/jpeg") == mimeType) return "jpeg";
+    if (QString("image/x-portable-bitmap") == mimeType) return "pbm";
+    if (QString("image/x-portable-graymap") == mimeType) return "pgm";
+    if (QString("image/png") == mimeType) return "png";
+    if (QString("image/x-portable-pixmap") == mimeType) return "ppm";
+    if (QString("image/x-xbitmap") == mimeType) return "xbm";
+    if (QString("image/x-xpixmap") == mimeType) return "xpm";
+    if (QString("image/x-eps") == mimeType) return "eps";
+    if (QString("image/svg+xml") == mimeType) return "svg";
     return QString();
 }
 
@@ -209,11 +181,7 @@ UMLViewImageExporterModel::~UMLViewImageExporterModel()
  * @return A QStringList with all the error messages that occurred during export.
  *         If the list is empty, all the views were exported successfully.
  */
-#if QT_VERSION >= 0x050000
-QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType, const QUrl &directory, bool useFolders) const
-#else
 QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType, const KUrl &directory, bool useFolders) const
-#endif
 {
     UMLApp *app = UMLApp::app();
 
@@ -221,19 +189,14 @@ QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType,
     QStringList errors;
 
     UMLViewList views = app->document()->viewIterator();
-    foreach (UMLView *view, views) {
-#if QT_VERSION >= 0x050000
-        QUrl url = QUrl::fromLocalFile(directory.path() + QLatin1Char('/') +
-                 getDiagramFileName(view->umlScene(), imageType, useFolders));
-#else
+    foreach (UMLView *view , views) {
         KUrl url = directory;
         url.addPath(getDiagramFileName(view->umlScene(), imageType, useFolders));
-#endif
 
         QString returnString = exportView(view->umlScene(), imageType, url);
         if (!returnString.isNull()) {
             // [PORT]
-            errors.append(view->umlScene()->name() + QLatin1String(": ") + returnString);
+            errors.append(view->umlScene()->name() + ": " + returnString);
         }
     }
 
@@ -249,17 +212,13 @@ QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType,
  *
  * If some problem occurs when exporting, an error message is returned.
  *
- * @param scene      The UMLScene to export.
- * @param imageType  The type of the image the view will be exported to.
- * @param url        The url where the image will be saved.
- * @return  The error message if some problem occurred when exporting, or
- *          QString() if all went fine.
+ * @param view The view to export.
+ * @param imageType The type of the image the view will be exported to.
+ * @param url The url where the image will be saved.
+ * @return The message error if some problem occurred when exporting, or
+ *         QString() if all went fine.
  */
-#if QT_VERSION >= 0x050000
-QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &imageType, const QUrl &url) const
-#else
 QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &imageType, const KUrl &url) const
-#endif
 {
     if (!scene) {
         return i18n("Empty scene");
@@ -267,22 +226,14 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     // create the needed directories
     if (!prepareDirectory(url)) {
-#if QT_VERSION >= 0x050000
-        return i18n("Cannot create directory: %1", url.path());
-#else
-        return i18n("Cannot create directory: %1", url.directory());
-#endif
+        return i18n("Can not create directory: %1", url.directory());
     }
 
     // The fileName will be used when exporting the image. If the url isn't local,
     // the fileName is the name of a temporal local file to export the image to, and then
     // upload it to its destiny
     QString fileName;
-#if QT_VERSION >= 0x050000
-    QTemporaryFile tmpFile;
-#else
     KTemporaryFile tmpFile;
-#endif
     if (url.isLocalFile()) {
         fileName = url.toLocalFile();
     } else {
@@ -292,7 +243,7 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     QRectF rect = scene->diagramRect();
     if (rect.isEmpty()) {
-        return i18n("Cannot save an empty diagram");
+        return i18n("Can not save an empty diagram");
     }
 
     // exporting the view to the file
@@ -302,14 +253,7 @@ QString UMLViewImageExporterModel::exportView(UMLScene* scene, const QString &im
 
     // if the file wasn't local, upload the temp file to the target
     if (!url.isLocalFile()) {
-#if QT_VERSION >= 0x050000
-        KIO::FileCopyJob *job = KIO::file_copy(QUrl::fromLocalFile(tmpFile.fileName()), url);
-        KJobWidgets::setWindow(job, UMLApp::app());
-        job->exec();
-        if (job->error()) {
-#else
         if (!KIO::NetAccess::upload(tmpFile.fileName(), url, UMLApp::app())) {
-#endif
             return i18n("There was a problem saving file: %1", url.path());
         }
     }
@@ -329,10 +273,10 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QSt
     if (scene) {
         if (useFolders) {
             qApp->processEvents();  //:TODO: still needed ???
-            return Model_Utils::treeViewBuildDiagramName(scene->ID()) + QLatin1Char('.') + imageType.toLower();
+            return Model_Utils::treeViewBuildDiagramName(scene->ID());
         }
         else {
-            return scene->name() + QLatin1Char('.') + imageType.toLower();
+            return scene->name() + '.' + imageType.toLower();;
         }
     }
     else {
@@ -349,38 +293,14 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLScene* scene, const QSt
  * @return True if the operation was successful,
  *         false if the directory didn't exist and couldn't be created.
  */
-#if QT_VERSION >= 0x050000
-bool UMLViewImageExporterModel::prepareDirectory(const QUrl &url) const
-#else
 bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
-#endif
 {
     // the KUrl is copied to get protocol, user and so on and then the path is cleaned
-#if QT_VERSION >= 0x050000
-    QUrl directory = url;
-    directory.setPath(QString());
-
-    // creates the directory and any needed parent directories
-    QStringList dirs = url.adjusted(QUrl::RemoveFilename).path().split(QDir::separator(), QString::SkipEmptyParts);
-    for (QStringList::ConstIterator it = dirs.constBegin() ; it != dirs.constEnd(); ++it) {
-        directory.setPath(directory.path() + QLatin1Char('/') + *it);
-        KIO::StatJob *statJob = KIO::stat(directory, KIO::StatJob::SourceSide, 0);
-        KJobWidgets::setWindow(statJob, UMLApp::app());
-        statJob->exec();
-        if (statJob->error()) {
-
-            KIO::MkdirJob* job = KIO::mkdir(directory);
-            if (!job->exec()) {
-                return false;
-            }
-        }
-    }
-#else
     KUrl directory = url;
-    directory.setPath(QString());
+    directory.setPath("");
 
     // creates the directory and any needed parent directories
-    QStringList dirs = url.directory().split(QDir::separator(), QString::SkipEmptyParts);
+    QStringList dirs = url.directory().split(QDir::separator(), QString::SkipEmptyParts );
     for (QStringList::ConstIterator it = dirs.constBegin() ; it != dirs.constEnd(); ++it) {
         directory.addPath(*it);
 
@@ -391,7 +311,6 @@ bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
             }
         }
     }
-#endif
 
     return true;
 }
@@ -416,15 +335,15 @@ bool UMLViewImageExporterModel::exportViewTo(UMLScene* scene, const QString &ima
     scene->clearSelected();
 
     QString imageMimeType = UMLViewImageExporterModel::imageTypeToMimeType(imageType);
-    if (imageMimeType == QLatin1String("image/x-dot")) {
+    if (imageMimeType == "image/x-dot") {
         if (!exportViewToDot(scene, fileName)) {
             return false;
         }
-    } else if (imageMimeType == QLatin1String("image/x-eps")) {
-        if (!exportViewToEps(scene, fileName)) {
+    } else if (imageMimeType == "image/x-eps") {
+        if (!exportViewToEps(scene, fileName, true)) {
             return false;
         }
-    } else if (imageMimeType == QLatin1String("image/svg+xml")) {
+    } else if (imageMimeType == "image/svg+xml") {
         if (!exportViewToSvg(scene, fileName)) {
             return false;
         }
@@ -464,51 +383,66 @@ bool UMLViewImageExporterModel::exportViewToDot(UMLScene* scene, const QString &
  *
  * @param scene    The scene to export.
  * @param fileName The name of the file where the image will be saved.
+ * @param isEPS    The file is an eps file and needs adjusting
+ *                 of the eps bounding box values.
  * @return True if the operation was successful,
  *         false if a problem occurred while exporting.
  */
-bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &fileName) const
+bool UMLViewImageExporterModel::exportViewToEps(UMLScene* scene, const QString &fileName, bool isEPS) const
 {
     if (!scene) {
         uWarning() << "Scene is null!";
         return false;
     }
 
-    qreal border = 0.01; // mm
-    QRectF rect = scene->diagramRect();
-    QSizeF paperSize(rect.size() * 25.4f / qApp->desktop()->logicalDpiX());
+    bool exportSuccessful = true;
 
-    QPrinter printer(QPrinter::ScreenResolution);
-    printer.setOutputFileName(fileName);
-#if QT_VERSION >= 0x050000
-    printer.setOutputFormat(QPrinter::PdfFormat);
-#else
-    printer.setOutputFormat(QPrinter::PostScriptFormat);
-#endif
-    printer.setColorMode(QPrinter::Color);
-    printer.setPaperSize(paperSize, QPrinter::Millimeter);
-    printer.setPageMargins(paperSize.width() * border, paperSize.height() * border, 0, 0, QPrinter::Millimeter);
-    printer.setResolution(qApp->desktop()->logicalDpiX());
-    printer.setOrientation(paperSize.width() < paperSize.height() ? QPrinter::Landscape : QPrinter::Portrait);
+    // print the image to a normal postscript file,
+    // do not clip so that everything ends up in the file
+    // regardless of "paper size"
+
+    // because we want to work with postscript
+    // user-coordinates, set to the resolution
+    // of the printer (which should be 72dpi here)
+    QPrinter *printer;
+
+    if (isEPS == false) {
+        printer = new QPrinter(QPrinter::PrinterResolution);
+    } else {
+        printer = new QPrinter(QPrinter::ScreenResolution);
+    }
+    printer->setOutputFileName(fileName);
+    printer->setOutputFormat(QPrinter::PostScriptFormat);
+    printer->setColorMode(QPrinter::Color);
 
     // do not call printer.setup(); because we want no user
     // interaction here
-    QPainter painter(&printer);
-
-    // add border around image
-    painter.scale(1 - border, 1 - border);
+    QPainter *painter = new QPainter(printer);
 
     // make sure the widget sizes will be according to the
     // actually used printer font, important for diagramRect()
     // and the actual painting
-    scene->forceUpdateWidgetFontMetrics(&painter);
+    scene->forceUpdateWidgetFontMetrics(painter);
 
-    scene->getDiagram(painter, rect);
+    UMLSceneRect rect = scene->diagramRect();
+    painter->translate(-rect.x(), -rect.y());
+    scene->getDiagram(*painter, rect);
 
+    int resolution = printer->resolution();
+
+    // delete painter and printer before we try to open and fix the file
+    delete painter;
+    delete printer;
+    if (isEPS) {
+        // modify bounding box from screen to eps resolution.
+        rect.setWidth( int(ceil(rect.width() * 72.0/resolution)) );
+        rect.setHeight( int(ceil(rect.height() * 72.0/resolution)) );
+        exportSuccessful = fixEPS(fileName, rect);
+    }
     // next painting will most probably be to a different device (i.e. the screen)
     scene->forceUpdateWidgetFontMetrics(0);
 
-    return true;
+    return exportSuccessful;
 }
 
 /**
@@ -527,12 +461,11 @@ bool UMLViewImageExporterModel::exportViewToSvg(UMLScene* scene, const QString &
     }
 
     bool exportSuccessful;
-    QRectF rect = scene->diagramRect();
+    UMLSceneRect rect = scene->diagramRect();
 
     QSvgGenerator generator;
     generator.setFileName(fileName);
     generator.setSize(rect.toRect().size());
-    generator.setResolution(qApp->desktop()->logicalDpiX());
     generator.setViewBox(QRect(0, 0, rect.width(), rect.height()));
     QPainter painter(&generator);
 
@@ -576,16 +509,67 @@ bool UMLViewImageExporterModel::exportViewToPixmap(UMLScene* scene, const QStrin
         return false;
     }
 
-    QRectF rect = scene->diagramRect();
-    float scale = 72.0f / qApp->desktop()->logicalDpiX();
-    QSizeF size = rect.size() * scale;
-    QPixmap diagram(size.toSize());
+    UMLSceneRect rect = scene->diagramRect();
+    QPixmap diagram(rect.width(), rect.height());
     scene->getDiagram(diagram, rect);
     bool exportSuccessful = diagram.save(fileName, qPrintable(imageType.toUpper()));
     DEBUG(DBG_IEM) << "saving to file " << fileName
-                   << ", imageType=" << imageType
-                   << ", width=" << rect.width()
-                   << ", height=" << rect.height()
-                   << ", successful=" << exportSuccessful;
+                   << " , imageType=" << imageType
+                   << " , width=" << rect.width()
+                   << " , height=" << rect.height()
+                   << " , successful=" << exportSuccessful;
     return exportSuccessful;
 }
+
+/**
+ * Fix the file 'fileName' to be a valid EPS containing the
+ * specified area (rect) of the diagram.
+ * Corrects the bounding box.
+ *
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
+bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const UMLSceneRect& rect) const
+{
+    // now open the file and make a correct eps out of it
+    QFile epsfile(fileName);
+    if (! epsfile.open(QIODevice::ReadOnly)) {
+        return false;
+    }
+    // read
+    QTextStream ts(&epsfile);
+    QString fileContent = ts.readAll();
+    epsfile.close();
+    
+    // read information
+    QRegExp rx("%%BoundingBox:\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)\\s*(-?[\\d\\.:]+)");
+    const int pos = rx.indexIn(fileContent);
+    if (pos < 0) {
+        uError() << fileName << ": cannot find %%BoundingBox";
+        return false;
+    }
+    
+    // write new content to file
+    if (! epsfile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+        uError() << fileName << ": cannot open file for writing";
+        return false;
+    }
+    
+    // be careful when rounding (ceil/floor) the BB, these roundings
+    // were mainly obtained experimentally...
+    const double epsleft = rx.cap(1).toFloat();
+    const double epstop = rx.cap(4).toFloat();
+    const int left = int(floor(epsleft));
+    const int right = int(ceil(epsleft)) + rect.width();
+    const int top = int(ceil(epstop)) + 1;
+    const int bottom = int(floor(epstop)) - rect.height() + 1;
+    
+    // modify content
+    fileContent.replace(pos,rx.cap(0).length(),
+                        QString("%%BoundingBox: %1 %2 %3 %4").arg(left).arg(bottom).arg(right).arg(top));
+    
+    ts << fileContent;
+    epsfile.close();
+    
+    return true;
+}
